package main

import (
	"flag"
	"fmt"
	"log"

	_ "net/http/pprof"

	"git.autistici.org/ale/autoradio"
	"git.autistici.org/ale/autoradio/fe"
	"git.autistici.org/ale/autoradio/instrumentation"
	"git.autistici.org/ale/autoradio/util"
)

var (
	domain      = flag.String("domain", "", "DNS domain to serve")
	publicIPs   = util.IPList("ip", "Public IP for this machine (may be specified more than once). If unset, the program will try to resolve the local hostname, or it will fall back to inspecting network devices.")
	dnsPort     = flag.Int("dns-port", 53, "DNS port")
	httpPort    = flag.Int("http-port", 80, "HTTP port")
	staticDir   = flag.String("static-dir", "/usr/share/autoradio/htdocs/static", "Static content directory")
	templateDir = flag.String("template-dir", "/usr/share/autoradio/htdocs/templates", "HTML templates directory")
	lbPolicy    = flag.String("lb-policy", "listeners_available,listeners_score,weighted", "Load balancing rules specification (see godoc documentation for details)")

	// Default DNS TTL (seconds).
	dnsTtl = 5
)

func main() {
	log.SetFlags(0)
	flag.Parse()

	if *domain == "" {
		log.Fatal("Must specify --domain")
	}

	if err := util.DetectPublicNetworkParams(publicIPs, nil, nil); err != nil {
		log.Fatal(err)
	}

	instrumentation.NewCounter("redirectord.restarts").Incr()

	client := autoradio.NewClient(autoradio.NewEtcdClient(false))

	dnsRed := fe.NewDNSRedirector(client, *domain, *publicIPs, dnsTtl)
	dnsRed.Start(fmt.Sprintf(":%d", *dnsPort))

	red, err := fe.NewHTTPRedirector(client, *domain, *lbPolicy, *staticDir, *templateDir)
	if err != nil {
		log.Fatal(err)
	}
	red.Run(fmt.Sprintf(":%d", *httpPort))
}
